@@ -2,3 +2,5 @@
 ( cd usr/lib64 ; ln -sf libgdiplus.so.0.0.0 libgdiplus.so.0 )
 ( cd usr/lib64 ; rm -rf libgdiplus.so )
 ( cd usr/lib64 ; ln -sf libgdiplus.so.0.0.0 libgdiplus.so )
+( cd usr/doc/libgdiplus-5.4 ; rm -rf COPYING )
+( cd usr/doc/libgdiplus-5.4 ; ln -sf /usr/share/automake-1.15/COPYING COPYING )
